@@ -15,12 +15,13 @@
  *																															*
  *********************************************************************************/
 #include "kbear.h"
+
 //-----------------------------------------------
 KBear::KBear()
 	:	QextMdiMainFrm( 0 ), localFileSys( 0L ),
 		localFileSysCaption( i18n("Your Local File System" ) ),
 		myClipBoard( new KBearClipBoard() ),
-		p_activeView( 0L )
+		p_activeView( 0L ), firstRun( false )
 {
 	openWithHandler = new KFileOpenWithHandler();
    //set application config file
@@ -43,20 +44,15 @@ KBear::KBear()
 	fillWindowMenu();
 	initLocalFileSys();
 	myConfig->setGroup("General Options");
-	if( myConfig->readBoolEntry( "First Run", true) ) {
-		// read default email for use as password on anonymous servers
-		KConfig* conf =  new KConfig("emaildefaults");
-		conf->setGroup("UserInfo");
-		str_emailDefault = conf->readEntry( "EmailAddress" );
-		myConfig->writeEntry( "Default Email", str_emailDefault );
-		delete conf;
+	firstRun = myConfig->readBoolEntry( "First Run", true );
+	if( firstRun )
    		slotWelcome();
-	}
-	myConfig->setGroup("View Options");
+   	myConfig->setGroup("View Options");
 	if( myConfig->readBoolEntry( "TopLevel Mode", false ) )
 		switchToToplevelMode();
 	else
 		switchToChildframeMode();
+
 }
 //-----------------------------------------------
 KBear::~KBear() {
@@ -67,6 +63,13 @@ KBear::~KBear() {
 void KBear::show() {
 	setPlainCaption( myCaption );
 	QextMdiMainFrm::show();
+	QApplication::restoreOverrideCursor();
+
+	myConfig->setGroup("General Options");
+	if( myConfig->readBoolEntry( "Run Tip Of Today", true ) )
+		slotRunTipOfToday();
+	if( firstRun)
+		slotFtpSiteManager();
 }
 //-----------------------------------------------
 void KBear::fillWindowMenu() {
@@ -132,6 +135,8 @@ void KBear::initMenuBar() {
 	settingsMenu->insertSeparator();
 	settingsAction->plug( settingsMenu );
 	settingsMenu->insertSeparator();
+	runTipAction->plug( settingsMenu );
+	settingsMenu->insertSeparator();
 	wizardAction->plug( settingsMenu );
 	///////////////////////////////////////////////////////////////////
 	// menuBar entry Help
@@ -182,6 +187,8 @@ void KBear::initToolBar() {
 	helpAction->plug( toolBar );
 	actionSeparator->plug( toolBar );
 	whatsThisAction->plug( toolBar );
+	actionSeparator->plug( toolBar );
+	runTipAction->plug( toolBar );
 }
 //-----------------------------------------------
 void KBear::initStatusBar() {
@@ -274,15 +281,17 @@ bool KBear::queryExit() {
 //-----------------------------------------------
 bool KBear::queryClose() {
 	myConfig->setGroup("General Options");
-	if( ! myConfig->readBoolEntry( "Confirm On Exit", true) || transferView->childCount() == 0 )
+	if( ! myConfig->readBoolEntry( "Confirm On Exit", true)
+			|| (transferView->childCount() == 0 && transferQueue.count() == 0) )
 		return true;
 	
-	KBearQueryExit* queryExitDlg = new KBearQueryExit( this, "KBearQueryExit");
-	queryExitDlg->getNumOfTransfers()->display( i18n("%1").arg(transferView->childCount()));
+	KBearQueryExit* queryExitDlg = new KBearQueryExit( this, "KBearQueryExit", true);
+	queryExitDlg->numOfTransfers->display( i18n("%1").arg(transferView->childCount()));
+	queryExitDlg->numOfQueuedTransfers->display( i18n("%1").arg(transferQueue.count()));
 	bool confirm = true;
-	queryExitDlg->getAskAgainCheckBox()->setChecked( ! confirm );
+	queryExitDlg->askAgainCheckBox->setChecked( ! confirm );
 	int accept = queryExitDlg->exec();
-	confirm = queryExitDlg->getAskAgainCheckBox()->isChecked();
+	confirm = queryExitDlg->askAgainCheckBox->isChecked();
 	delete queryExitDlg;
 	if ( accept == QDialog::Accepted ) {
 		myConfig->writeEntry( "Confirm On Exit", !confirm );
@@ -399,6 +408,8 @@ void KBear::slotStatusHelpMsg(const QString &text){
 //-----------------------------------------------
 /**  undocks all view windows (unix-like) */
 void KBear::switchToToplevelMode(){
+	if( isInTopLevelMode() )
+		return;
 	QextMdiMainFrm::switchToToplevelMode();
 
 	if( b_rememberChildPositions )
@@ -413,6 +424,7 @@ void KBear::switchToToplevelMode(){
 			connect( view, SIGNAL(viewPositionChanged() ),
 						this, SLOT( saveChildViewPositions() ) );
 	}
+//	QApplication::restoreOverrideCursor();
 }
 //-----------------------------------------------
 /** docks all view windows (Windows-like) */
@@ -426,6 +438,7 @@ void KBear::switchToChildframeMode(){
 	setGeometry( rect.x(), rect.y(), width(), height() );
 	if( b_autoChildFrameMode )
 		setChildFrameMode( currentChildFrameMode );
+//	QApplication::restoreOverrideCursor();
 }
 //-----------------------------------------------
 /** just additionally fits the system menu button position to the menu position */
@@ -521,7 +534,7 @@ void KBear::readOptions() {
 	// initialize the recent file list
 	int numOfEntries = myConfig->readListEntry("Recent Connections",recentConnections);
 	for (int i=0; i < numOfEntries; i++)
-		recentFtpMenu->insertItem(recentConnections.at( i ) );
+		recentFtpMenu->insertItem( QString::fromUtf8(recentConnections.at( i ) ) );
 	
 	IDS_STARTPAGE = myConfig->readEntry( "Start Page" , IDS_STARTPAGE );
 
@@ -601,18 +614,18 @@ void KBear::slotFtpClearRecent() {
 }
 //-----------------------------------------------
 void KBear::addRecentFile(const QString &file) {
-	if(recentConnections.contains(file))
+	if(recentConnections.contains(file.utf8()))
 		return; // it's already there
 
 	if( recentConnections.count() >= 10)
 		recentConnections.remove(recentConnections.last());
 	
-	recentConnections.prepend(file);
+	recentConnections.prepend(file.utf8());
 
 	recentFtpMenu->clear();
 
 	for ( int i =0 ; i < (int)recentConnections.count(); i++)
-		recentFtpMenu->insertItem(recentConnections.at(i));
+		recentFtpMenu->insertItem(QString::fromUtf8(recentConnections.at(i)));
 }
 //-----------------------------------------------
 void KBear::showAboutApplication () {
@@ -632,12 +645,15 @@ void KBear::slotCut(){
 		myClipBoard->setCut( true );
 	if( isInTopLevelMode() )
 		p_activeView = 0L;
+
 }
 //-----------------------------------------------
 /**  */
 void KBear::slotCopy(){
-	if( isInTopLevelMode() && ! p_activeView )
+	if( isInTopLevelMode() && ! p_activeView ) {
+		showActionDisabledInTopLevelMode();
 		return;
+	}
 	KBearFtpView* current = (KBearFtpView*)p_activeView;
 	KURL::List urlList = current->myHighlightedItems();
 	if( ! urlList.isEmpty() ) {
@@ -651,8 +667,10 @@ void KBear::slotCopy(){
 //-----------------------------------------------
 /**  */
 void KBear::slotPaste() {
-	if( isInTopLevelMode() && ! p_activeView )
+	if( isInTopLevelMode() && ! p_activeView ) {
+		showActionDisabledInTopLevelMode();
 		return;
+	}
 	KBearFtpView* current = (KBearFtpView*)p_activeView;
 	pasteAction->setEnabled( false );
 	if( myClipBoard->isEmpty() )
@@ -671,13 +689,15 @@ void KBear::slotPaste() {
 //-----------------------------------------------
 /**  */
 void KBear::slotFind(){
-	if( isInTopLevelMode() && ! p_activeView )
+	if( isInTopLevelMode() && ! p_activeView ) {
+		showActionDisabledInTopLevelMode();
 		return;
+	}
 	KBearFtpView* current = (KBearFtpView*)p_activeView;
-	KBearSearchDialog myDialog( this, "SearchDialog" );
+	KBearSearch myDialog( this, "SearchDialog", true );
 	if( myDialog.exec() == QDialog::Accepted ){
-		bool caseSensitive = myDialog.getCaseSensitiveCheckBox()->isChecked();	
-		QString name = myDialog.getSearchEdit()->text();
+		bool caseSensitive = myDialog.caseSensitiveCheckBox->isChecked();	
+		QString name = myDialog.searchEdit->text();
 		((KBearFtpView*)current)->myOperator()->setCurrentItem( name, caseSensitive );
 	}
 	if( isInTopLevelMode() )
@@ -690,7 +710,9 @@ void KBear::slotWelcome() {
 	KBearWizard myWiz( this, "Wizard" );
 	setDialogSettings( myWiz.settingsWidget(), myWiz.mixedSettingsWidget(), myWiz.childFrameModeSettings() );
 	myWiz.exec();
-	changeSettings( myWiz.settingsWidget(), myWiz.mixedSettingsWidget(), myWiz.childFrameModeSettings() );	
+	changeViewSettings( myWiz.settingsWidget() );	
+	changeMixedSettings( myWiz.mixedSettingsWidget() );	
+	changeChildFrameModeSettings( myWiz.childFrameModeSettings() );	
 //	KProtocolManager::reparseConfiguration();
 }
 //-----------------------------------------------
@@ -701,134 +723,168 @@ void KBear::slotShowHelp(){
 //-----------------------------------------------
 /** open a dialog for setting general application settings */
 void KBear::slotSettings(){
-	KBearSettingsDialog dialog( this, "SettingsDialog" );
-	ViewSettingsWidget* view = dialog.viewSettingsWidget();
-	MixedSettingsWidget* mixed = dialog.mixedSettingsWidget();
-	ChildFrameModeSettings* child = dialog.childFrameModeSettings();
+	settingsDialog = new KBearSettingsDialog( this, "SettingsDialog" );
+	connect( settingsDialog, SIGNAL( applyClicked() ), this, SLOT( slotApplySettings() ) );
+	ViewSettingsWidget* view = settingsDialog->viewSettingsWidget();
+	MixedSettingsWidget* mixed = settingsDialog->mixedSettingsWidget();
+	ChildFrameModeSettings* child = settingsDialog->childFrameModeSettings();
 	setDialogSettings( view, mixed, child );
-	if( dialog.exec() == QDialog::Accepted ) {
-		changeSettings( view, mixed, child );
+	if( settingsDialog->exec() == QDialog::Accepted ) {
+		changeViewSettings( view );
+		changeMixedSettings( mixed );
+		changeChildFrameModeSettings( child );
 //		KProtocolManager::reparseConfiguration();
 	}
+	delete settingsDialog;
 }
 //-----------------------------------------------
 void KBear::setDialogSettings( ViewSettingsWidget* w, MixedSettingsWidget* m, ChildFrameModeSettings* c ){
 	myConfig->setGroup("View Settings");
 	bool viewType = myConfig->readBoolEntry("Show DetailView", true);
-	w->detailedViewButton()->setChecked( viewType );
-	w->iconViewButton()->setChecked( ! viewType );
-	w->treeViewCheckBox()->setChecked( myConfig->readBoolEntry("Show TreeView", true) );
-	w->transferViewCheckBox()->setChecked( transferViewToggleAction->isChecked() );
-	w->toolBarCheckBox()->setChecked( toolBarToggleAction->isChecked() );
-	w->statusBarCheckBox()->setChecked( statusBarToggleAction->isChecked() );
-	w->taskBarCheckBox()->setChecked( taskBarToggleAction->isChecked() );
+	w->p_detailedViewButton->setChecked( viewType );
+	w->p_iconViewButton->setChecked( ! viewType );
+	w->p_treeViewCheckBox->setChecked( myConfig->readBoolEntry("Show TreeView", true) );
+	w->p_transferViewCheckBox->setChecked( transferViewToggleAction->isChecked() );
+	w->p_toolBarCheckBox->setChecked( toolBarToggleAction->isChecked() );
+	w->p_statusBarCheckBox->setChecked( statusBarToggleAction->isChecked() );
+	w->p_taskBarCheckBox->setChecked( taskBarToggleAction->isChecked() );
 	
 	myConfig->setGroup("View Options");
 	if( myConfig->readBoolEntry( "TopLevel Mode", false) )
-		w->topLevelRadioButton()->setChecked( true );
+		w->p_topLevelRadioButton->setChecked( true );
 	else
-		w->childFrameRadioButton()->setChecked( true );
-	w->rememberPosCheckBox()->setChecked( b_rememberChildPositions );
+		w->p_childFrameRadioButton->setChecked( true );
+	w->p_rememberPosCheckBox->setChecked( b_rememberChildPositions );
 	c->setDefaultChildFrameMode( defaultChildFrameMode );
-	c->useAutoChildFrameMode()->setChecked( b_autoChildFrameMode );
+	c->p_useAutoChildFrameMode->setChecked( b_autoChildFrameMode );
 	
 	myConfig->setGroup("General Options");
 	if( myConfig->readBoolEntry( "First Run", true) )
-		w->localFileSysCheckBox()->setChecked( true );
+		w->p_localFileSysCheckBox->setChecked( true );
 	else
-		w->localFileSysCheckBox()->setChecked( localFileSysToggleAction->isChecked() );
-	w->runSettingsCheckBox()->setChecked( myConfig->readBoolEntry( "Run Time Settings", true) );
-	m->confirmExitCheckBox()->setChecked( myConfig->readBoolEntry( "Confirm On Exit", true) );
-	m->queueTransferCheckBox()->setChecked( b_queueTransfers );
+		w->p_localFileSysCheckBox->setChecked( localFileSysToggleAction->isChecked() );
+	w->p_runSettingsCheckBox->setChecked( myConfig->readBoolEntry( "Run Time Settings", true) );
+	m->p_confirmExitCheckBox->setChecked( myConfig->readBoolEntry( "Confirm On Exit", true) );
+	m->p_runTipCheckBox->setChecked( myConfig->readBoolEntry( "Run Tip Of Today", true) );
+	m->p_queueTransferCheckBox->setChecked( b_queueTransfers );
 	m->setDefaultWebPage( IDS_STARTPAGE );
 	m->setDefaultEmail( str_emailDefault );
-//	m->setAutoResume( myConfig->readBoolEntry( "Auto Resume", false) );
+#warning FIXME 	m->autoResumeCheckBox()->setChecked( KProtocolManager::autoResume() ) as soon as kdelibs are changed
+	m->p_autoResumeCheckBox->setChecked( KProtocolManager::autoResume() );
+#warning FIXME 	m->partExtensionCheckBox()->setChecked( KProtocolManager::markPartial() ) as soon as kdelibs are changed
+	m->p_partExtensionCheckBox->setChecked( ! KProtocolManager::markPartial() );
 	w->slotViewSelect();
 }
 //-----------------------------------------------
-void KBear::changeSettings( ViewSettingsWidget* w, MixedSettingsWidget* m, ChildFrameModeSettings* c ){
-	emit viewSettingsChanged( w->detailedViewButton()->isChecked(),
-													w->iconViewButton()->isChecked(),
-													w->treeViewCheckBox()->isChecked() );
+void KBear::slotApplySettings(){
+	switch( settingsDialog->activePageIndex() ) {
+		case 0:
+			changeViewSettings( settingsDialog->viewSettingsWidget() ); break;
+		case 1:
+			changeChildFrameModeSettings( settingsDialog->childFrameModeSettings() ); break;
+		case 2:
+			changeMixedSettings( settingsDialog->mixedSettingsWidget() ); break;
+	}
+}
+//-----------------------------------------------
+/** No descriptions */
+void KBear::changeViewSettings( ViewSettingsWidget* w ){
 													
-	if( w->transferViewCheckBox()->isChecked() != transferViewToggleAction->isChecked() )
+	if( w->p_transferViewCheckBox->isChecked() != transferViewToggleAction->isChecked() )
 		transferViewToggleAction->activate();
-	if( w->toolBarCheckBox()->isChecked() != toolBarToggleAction->isChecked() )
+	if( w->p_toolBarCheckBox->isChecked() != toolBarToggleAction->isChecked() )
 		toolBarToggleAction->activate();
-	if( w->statusBarCheckBox()->isChecked() != statusBarToggleAction->isChecked() )
+	if( w->p_statusBarCheckBox->isChecked() != statusBarToggleAction->isChecked() )
 		statusBarToggleAction->activate();
-	if( w->taskBarCheckBox()->isChecked() != taskBarToggleAction->isChecked() )
+	if( w->p_taskBarCheckBox->isChecked() != taskBarToggleAction->isChecked() )
 		taskBarToggleAction->activate();
-	if( w->localFileSysCheckBox()->isChecked() != localFileSysToggleAction->isChecked() )
+	if( w->p_localFileSysCheckBox->isChecked() != localFileSysToggleAction->isChecked() )
 		localFileSysToggleAction->activate();
 	
 	myConfig->setGroup("View Options");
-	bool topLevel = w->topLevelRadioButton()->isChecked();
+	bool topLevel = w->p_topLevelRadioButton->isChecked();
 	myConfig->writeEntry( "TopLevel Mode", topLevel );
-	b_rememberChildPositions = w->rememberPosCheckBox()->isChecked();
+	b_rememberChildPositions = w->p_rememberPosCheckBox->isChecked();
 	myConfig->writeEntry( "Remember Child Positions", b_rememberChildPositions );
-	defaultChildFrameMode = c->getDefaultChildFrameMode();
-	currentChildFrameMode = defaultChildFrameMode;
-	b_autoChildFrameMode = c->useAutoChildFrameMode()->isChecked();
-	myConfig->writeEntry( "Use Auto ChildFrame Mode", b_autoChildFrameMode );
-	myConfig->writeEntry( "ChildFrame Mode", defaultChildFrameMode );
+	
+	myConfig->setGroup("General Options");
+	myConfig->writeEntry( "Run Time Settings", w->p_runSettingsCheckBox->isChecked() );
+// emit the changes
+	emit viewSettingsChanged( w->p_detailedViewButton->isChecked(),
+													w->p_iconViewButton->isChecked(),
+													w->p_treeViewCheckBox->isChecked() );
+
 	if( topLevel )
 		switchToToplevelMode();
 	else
 		switchToChildframeMode();
-		
-	
-	myConfig->setGroup("General Options");
-	myConfig->writeEntry( "Run Time Settings", w->runSettingsCheckBox()->isChecked() );
-	myConfig->writeEntry( "Confirm On Exit", m->confirmExitCheckBox()->isChecked() );
-	b_queueTransfers = m->queueTransferCheckBox()->isChecked();
 
-//	myConfig->writeEntry( "Auto Resume", m->autoResume() );
-//	KProtocolManager::setAutoResume( m->autoResume() );
+}
+//-----------------------------------------------
+/** No descriptions */
+void KBear::changeMixedSettings( MixedSettingsWidget* m ){
+	myConfig->setGroup("General Options");
+	myConfig->writeEntry( "Confirm On Exit", m->p_confirmExitCheckBox->isChecked() );
+	b_queueTransfers = m->p_queueTransferCheckBox->isChecked();
+	myConfig->writeEntry( "Run Tip Of Today", m->p_runTipCheckBox->isChecked() );
+
+#warning FIXME 	KProtocolManager::setAutoResume as soon as kdelibs are changed
+	KProtocolManager::setAutoResume( m->p_autoResumeCheckBox->isChecked() );
+#warning FIXME 	KProtocolManager::setMarkPartial as soon as kdelibs are changed
+	KProtocolManager::setMarkPartial( ! m->p_partExtensionCheckBox->isChecked() );
 	IDS_STARTPAGE = m->defaultWebPage();
 	myConfig->writeEntry( "Start Page", IDS_STARTPAGE );
 	str_emailDefault = m->defaultEmail();
 	myConfig->writeEntry( "Default Email", str_emailDefault );
 }
 //-----------------------------------------------
+/** No descriptions */
+void KBear::changeChildFrameModeSettings( ChildFrameModeSettings* c ){
+	myConfig->setGroup("View Options");
+	defaultChildFrameMode = c->getDefaultChildFrameMode();
+	currentChildFrameMode = defaultChildFrameMode;
+	b_autoChildFrameMode = c->p_useAutoChildFrameMode->isChecked();
+	myConfig->writeEntry( "Use Auto ChildFrame Mode", b_autoChildFrameMode );
+	myConfig->writeEntry( "ChildFrame Mode", defaultChildFrameMode );
+}
+//-----------------------------------------------
 void KBear::startTransfer( KBearFtpView* view, KURL::List& urlList, bool move ){
 	KURL dest = view->getCurrentURL();
-	KBearTransferQueueItem* qItem= new KBearTransferQueueItem;
 	for ( KURL::List::Iterator it = urlList.begin(); it != urlList.end(); ++it ) {
 		
-		if( b_queueTransfers && it != urlList.begin() ) {
+		if( b_queueTransfers && (it != urlList.begin() || transferView->childCount()>0)) {
+			KBearTransferQueueItem* qItem= new KBearTransferQueueItem;
 			qItem->move =  move;
 			qItem->source =  (*it);
 			qItem->dest =  dest;
 			qItem->host =  urlList.first().host();
-			transferQueue.enqueue( (const KBearTransferQueueItem*)qItem );
+			transferQueue.enqueue( /*(const KBearTransferQueueItem*)*/qItem );
 		}
 		else {
 			KIO::Job* transferJob = activateTransfer( (*it), dest, urlList.first().host(), move );
 			// only call rereaddir() on ftp sites, on local filesys KDirWatch takes care of updating the view
-			connect( (KIO::Job*)transferJob, SIGNAL( result( KIO::Job*)),
-								this, SLOT( slotDeleteItem( KIO::Job* ) ));
 			if( view->getCurrentURL().protocol() =="ftp" )
 				connect( (KIO::Job*)transferJob, SIGNAL( result( KIO::Job*)),
 								view->myOperator(), SLOT( rereadDir()));
+
 		}
 	}
 }
 //-----------------------------------------------
-KIO::Job* KBear::activateTransfer( KURL source, KURL dest, QString host, bool move )
-{
-	KIO::Job* transferJob = 0;
+KIO::Job* KBear::activateTransfer( KURL source, KURL dest, QString host, bool move ) {
+	KIO::CopyJob* transferJob = 0;
 	if( move ) {
 		transferJob = KIO::move( source, dest, false );
+		connect( (KIO::Job*)transferJob, SIGNAL( result( KIO::Job*)),
+								this, SLOT( slotDeleteItem( KIO::Job* ) ));
 		urlDeleteMap.insert( transferJob, source );
 	}
 	else
 		transferJob = KIO::copy( source, dest, false );
 
-	KBearTransferViewItem* i = new KBearTransferViewItem( transferJob, transferView, host, move );
+	KBearTransferViewItem* item = new KBearTransferViewItem( transferJob, transferView, host, move );
+	connect( item, SIGNAL( finished()), this, SLOT( slotStartNextTransfer() ));
 
-	connect( i, SIGNAL( removeMe( KBearTransferViewItem*)),
-					this, SLOT( slotRemoveTransferViewItem(KBearTransferViewItem*)));
 	return transferJob;
 }
 //-----------------------------------------------
@@ -838,9 +894,7 @@ void KBear::slotDeleteItem( KIO::Job* job ) {
 	urlDeleteMap.remove( job );
 }
 //-----------------------------------------------
-void KBear::slotRemoveTransferViewItem( KBearTransferViewItem* i ){
-	delete (QListViewItem*)(i->myTreeViewItem());
-	delete i;
+void KBear::slotStartNextTransfer(){
 	if( b_queueTransfers && transferQueue.count() > 0 ) {
 		KBearTransferQueueItem* qItem = transferQueue.dequeue();
 		//start next pending transfer
@@ -900,6 +954,9 @@ void KBear::setupActions(){
 	settingsAction = new KAction( i18n("&General Settings"), 0,
 						this, SLOT( slotSettings() ), myActionCollection, "settings" );
 
+	runTipAction = new KAction( i18n("Run &Tip of today"), "ktip", KAccel::stringToKey("F10"),
+						this, SLOT( slotRunTipOfToday() ), myActionCollection, "tip of today" );
+
 	wizardAction = new KAction( i18n("Run &Wizard..."), "wizard",0,
 						this, SLOT( slotWelcome() ), myActionCollection, "wizard" );
 	
@@ -922,7 +979,7 @@ void KBear::setupActions(){
 	quickConnectAction->setStatusText( i18n("Open a new connection") );
 	disConnectAction->setStatusText( i18n("Close current connection") );
 	siteManagerAction->setStatusText( i18n("Open the Sitemanager") );
-	helpAction->setStatusText( i18n("Open the Sitemanager") );
+//	helpAction->setStatusText( i18n("Open the Sitemanager") );
 // setup whats this
 	quickConnectAction->setWhatsThis( i18n("Click this button to open a new connection.\n\n"
                   "You can also select the Quick Connect command from the FTP menu.") );
@@ -930,6 +987,8 @@ void KBear::setupActions(){
                   "You can also select the Close Connection command from the FTP menu.") );
 	siteManagerAction->setWhatsThis( i18n("Click this button to open the Sitemanager.\n\n"
                   "You can also select the Open Sitemanager command from the FTP menu.") );
+	runTipAction->setWhatsThis( i18n("Click this button to run the Tip of today dialog.\n\n"
+                  "You can also select the Run Tip of today command from the Settings menu.") );
 	emailAction->setWhatsThis( i18n("Click this button to open KMail.") );
 	browserAction->setWhatsThis( i18n("Click this button to open Konqueror Web Browser.") );
 
@@ -947,6 +1006,7 @@ void KBear::setupActions(){
 	myActionCollection->insert( siteManagerAction );
 	myActionCollection->insert( clearRecentAction );
 	myActionCollection->insert( settingsAction );
+	myActionCollection->insert( runTipAction );
 	myActionCollection->insert( wizardAction );
 	myActionCollection->insert( emailAction );
 	myActionCollection->insert( browserAction );
@@ -974,8 +1034,10 @@ bool KBear::detailedViewIsSet() const {
 }
 //-----------------------------------------------
 void KBear::slotSelectAll(){
-	if( isInTopLevelMode() && ! p_activeView )
+	if( isInTopLevelMode() && ! p_activeView ) {
+		showActionDisabledInTopLevelMode();
 		return;
+	}
 	KBearDirOperator* dirOp = ((KBearFtpView*)p_activeView)->myOperator();
 	((KFileView*)dirOp->view())->selectAll();
 	if( isInTopLevelMode() )
@@ -983,8 +1045,10 @@ void KBear::slotSelectAll(){
 }
 //-----------------------------------------------
 void KBear::slotClearSelection(){
-	if( isInTopLevelMode() && ! p_activeView )
+	if( isInTopLevelMode() && ! p_activeView ) {
+		showActionDisabledInTopLevelMode();
 		return;
+	}
 	KBearDirOperator* dirOp = ((KBearFtpView*)p_activeView)->myOperator();
 	((KFileView*)dirOp->view())->clearSelection();
 	if( isInTopLevelMode() )
@@ -992,8 +1056,10 @@ void KBear::slotClearSelection(){
 }
 //-----------------------------------------------
 void KBear::slotInvertSelection(){
-	if( isInTopLevelMode() && ! p_activeView )
+	if( isInTopLevelMode() && ! p_activeView ) {
+		showActionDisabledInTopLevelMode();
 		return;
+	}
 	KBearDirOperator* dirOp = ((KBearFtpView*)p_activeView)->myOperator();
 	((KFileView*)dirOp->view())->invertSelection();
 	if( isInTopLevelMode() )
@@ -1131,3 +1197,20 @@ void KBear::slotClearActiveView() {
 	p_activeView = 0L;
 }
 //-----------------------------------------------
+/** Runs the tip of today dialog */
+void KBear::slotRunTipOfToday(){
+	bool runOnStart = myConfig->readBoolEntry( "Run Tip Of Today", true);
+	KBearTipOfToday tipOfToday( this, "KBearTipOfToday");
+	tipOfToday.runTipCheckBox->setChecked( runOnStart );
+	tipOfToday.run();
+	myConfig->setGroup("General Options");
+	myConfig->writeEntry( "Run Tip Of Today", tipOfToday.runTipOfToday() );
+}
+//-----------------------------------------------
+/** No descriptions */
+void KBear::showActionDisabledInTopLevelMode() {
+	KMessageBox::information ( this, i18n("When working in Toplevel mode you can only use this action\n"
+													"by rightclicking in the view where you want the action to be performed."),
+													i18n("Action disabled") );
+}
+//-----------------------------------------------
