@@ -49,8 +49,6 @@ void KBearDirOperator::activatedMenu( const KFileViewItem* item ) {
 		activatedItem = (KFileViewItem*)item;
 		// currently shred is only possible on local file system
 		shredAction->setEnabled( fileReader()->url().isLocalFile() );
-		// no reason to be able to select browse without an item
-//		browserAction->setEnabled( true );
 		openAction->setEnabled( true );
 		openWithAction->setEnabled( true );
 		fileActionMenu->popup( QCursor::pos() );
@@ -58,7 +56,6 @@ void KBearDirOperator::activatedMenu( const KFileViewItem* item ) {
 	else {
 		openAction->setEnabled( false );
 		openWithAction->setEnabled( false );
-//		browserAction->setEnabled( false );
 		((KActionMenu*)actionCollection()->action("popupMenu"))->popup( QCursor::pos() );
 	}
 }
@@ -78,36 +75,40 @@ void KBearDirOperator::setHomeURL( const KURL& url ){
 }
 //-----------------------------------------------
 void KBearDirOperator::slotDelete(){
-	QStringList strList;
-	QList<KFileViewItem>* fileList = (QList<KFileViewItem>*)view()->selectedItems();
-	for( unsigned int i = 0; i < fileList->count(); i++)
-		strList << fileList->at( i )->urlString();
-
-	int answer = KMessageBox::questionYesNoList( this,
-						i18n("Do you really want to delete the file(s) ?"),
-						strList, i18n("Delete") );
-	if( answer == KMessageBox::Yes ) {
-		KURL::List urlList( strList );
-		KIO::DeleteJob* deleteJob = KIO::del( urlList, false, false );
-		connect( deleteJob, SIGNAL( result( KIO::Job*) ), this, SLOT( slotDeleteFinished( KIO::Job* ) ) );
-		p_myFtpView->slotStatusMsg( 0, i18n("Deleting file(s)") );
-	}
+	deleteFiles( false );
 }
 //-----------------------------------------------
 void KBearDirOperator::slotShred(){
+	deleteFiles( true );
+}
+//-----------------------------------------------
+void KBearDirOperator::deleteFiles( bool shred){
 	QStringList strList;
+	QStringList showStrList;
 	QList<KFileViewItem>* fileList = (QList<KFileViewItem>*)view()->selectedItems();
-	for( unsigned int i = 0; i < fileList->count(); i++)
-		strList << fileList->at( i )->urlString();
+	for( unsigned int i = 0; i < fileList->count(); i++) {
+		if(fileList->at( i )->isDir()){
+			strList << fileList->at( i )->url().url(+1);
+			showStrList << fileList->at( i )->url().prettyURL(+1);
+		}
+		else {
+			strList << fileList->at( i )->url().url();
+			showStrList << fileList->at( i )->url().prettyURL();
+		}	
+	
+	}
 
 	int answer = KMessageBox::questionYesNoList( this,
 						i18n("Do you really want to delete the file(s) ?"),
-						strList, i18n("Delete") );
+						showStrList, i18n("Delete") );
 	if( answer == KMessageBox::Yes ) {
 		KURL::List urlList( strList );
-		KIO::DeleteJob* shredJob = KIO::del( urlList, true, false );
-		connect( shredJob, SIGNAL( result( KIO::Job*) ), this, SLOT( slotDeleteFinished( KIO::Job* ) ) );
-		p_myFtpView->slotStatusMsg( 0, i18n("Shredding file(s)") );
+		KIO::DeleteJob* deleteJob = KIO::del( urlList, shred, false );
+		connect( deleteJob, SIGNAL( result( KIO::Job*) ), this, SLOT( slotDeleteFinished( KIO::Job* ) ) );
+		if( shred )
+			p_myFtpView->slotStatusMsg( 0, i18n("Shredding file(s)") );
+		else
+			p_myFtpView->slotStatusMsg( 0, i18n("Deleting file(s)") );
 	}
 }
 //-----------------------------------------------
@@ -118,7 +119,7 @@ void KBearDirOperator::slotDeleteFinished( KIO::Job* /*job*/ ){
 		job->showErrorDialog( this ); // display error message
 	else
 */
-//		rereadDir();
+		rereadDir();
 }
 //-----------------------------------------------
 void KBearDirOperator::slotProperties(){
@@ -377,6 +378,8 @@ void KBearDirOperator::setupActionMenus() {
 	actMenu->insert( p_myFtpView->myApp()->actionCollection()->action("paste") );
 	actMenu->insert( actionCollection()->action("separator"));
 	actMenu->insert( p_myFtpView->myApp()->actionCollection()->action("select all") );
+	actMenu->insert( p_myFtpView->myApp()->actionCollection()->action("clear selection") );
+	actMenu->insert( p_myFtpView->myApp()->actionCollection()->action("invert selection") );
 	actMenu->insert( actionCollection()->action("separator"));
 	actMenu->insert( p_myFtpView->myApp()->actionCollection()->action("find") );
 	actMenu->insert( actionCollection()->action("separator"));
@@ -394,6 +397,8 @@ void KBearDirOperator::setupActionMenus() {
 	fileActionMenu->insert( p_myFtpView->myApp()->actionCollection()->action("paste") );
 	fileActionMenu->insert( actionCollection()->action("separator"));
 	fileActionMenu->insert( p_myFtpView->myApp()->actionCollection()->action("select all") );
+	fileActionMenu->insert( p_myFtpView->myApp()->actionCollection()->action("clear selection") );
+	fileActionMenu->insert( p_myFtpView->myApp()->actionCollection()->action("invert selection") );
 	fileActionMenu->insert( actionCollection()->action("separator"));
 	fileActionMenu->insert( p_myFtpView->myApp()->actionCollection()->action("find") );
 	fileActionMenu->insert( actionCollection()->action("separator"));
@@ -487,8 +492,7 @@ void KBearDirOperator::slotToggleTreeView(){
 //-----------------------------------------------
 void KBearDirOperator::slotSetDetailedListViewMode(){
 	if( detailedListAction->isChecked() ) {
-		KFileView* v = new KBearFileDetailView( this,"DetailView" );
-		setView( v );
+		setView( new KBearFileDetailView( this,"DetailView" ) );
 		((KFileView*)view())->setViewMode( KFileView::All );
 		((KFileView*)view())->setSelectionMode( KFile::Extended );
 		connect( ((KBearFileDetailView*)view()), SIGNAL(dropped(KURL::List)),
