@@ -204,13 +204,13 @@ void KBearSiteManager::slotRemoveButton(){
 		int exit = 0;
 		if( siteInf->description == "group" ) {
 			exit = KMessageBox::warningContinueCancel (this, 	i18n("Do you really want to remove the group:\n"+
-										siteTreeView->selectedItem()->text(0)
+										siteTreeView->selectedItem()->text(0).utf8()
 										+"\nfrom your site list ?\n"+
 										"All sub groups and sites will be removed as well."), i18n("Remove..."), i18n("Continue"));
 		}
 		else {
 			exit = KMessageBox::warningContinueCancel (this, 	i18n("Do you really want to remove the site:\n"+
-										siteTreeView->selectedItem()->text(0)
+										siteTreeView->selectedItem()->text(0).utf8()
 										+"\nfrom your site list ?\n"), i18n("Remove..."), i18n("Continue"));
 		}
 		if( exit == KMessageBox::Continue ) {
